Package: ModToppLeone
Type: Package
Title: Modified Topp-Leone Distribution: Properties, Estimation, and
        Applications
Version: 0.1.0
Authors@R: c(
    person("Shikhar", "Tyagi", email = "shikhar1093tyagi@gmail.com", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-1606-0844")),
    person("Abhishek", "Tyagi", email = "abhishektyagi033@gmail.com", role = "aut"),
    person("Arvind", "Pandey", email = "arvindmzu@gmail.com", role = "aut"),
    person("Bhupendra", "Singh", email = "bhupendra.rana@gmail.com", role = "aut"),
    person("Vrijesh", "Tripathi", email = "vrijesh.tripathi@uwi.edu", role = "aut")
  )
Description: Provides density, cumulative distribution function, quantile function, random number generation, survival function, hazard rate function, statistical properties, classical point and interval estimation (maximum likelihood, ordinary least squares, weighted least squares, Cramer-von Mises, and maximum product of spacings), Bayesian estimation under symmetric and asymmetric loss functions (squared error, entropy, precautionary, and generalized entropy loss functions) with highest posterior density intervals, censoring schemes (random, Type-I, Type-II, and progressive Type-II censoring), and real data applications for the 'Modified Topp-Leone' distribution. Methods are based on Singh et al. (2025) <https://statassoc.or.th>, Cheng and Amin (1983) <doi:10.1111/j.2517-6161.1983.tb01267.x>, Swain et al. (1988) <doi:10.1080/00949658808811094>, Chen and Shao (1999) <doi:10.1080/10618600.1999.10474802>, and Balakrishnan and Aggarwala (2000) <doi:10.1007/978-1-4612-1178-5>.
License: GPL (>= 3)
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5.0)
Imports: stats, graphics
Suggests: knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-08-05 02:51:05 UTC; shikhar tyagi
Author: Shikhar Tyagi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1606-0844>),
  Abhishek Tyagi [aut],
  Arvind Pandey [aut],
  Bhupendra Singh [aut],
  Vrijesh Tripathi [aut]
Maintainer: Shikhar Tyagi <shikhar1093tyagi@gmail.com>
Repository: CRAN
Date/Publication: 2026-08-09 08:40:18 UTC

# Generated by roxygen2: do not edit by hand

export(bayes_mtl)
export(cvm_mtl)
export(dmtl)
export(entropy_mtl)
export(fit_mtl)
export(hmtl)
export(inequality_mtl)
export(mean_mtl)
export(meandev_mtl)
export(mle_censor_mtl)
export(mle_mtl)
export(mode_mtl)
export(moments_mtl)
export(mpl_mtl)
export(mps_mtl)
export(mrl_mtl)
export(ols_mtl)
export(order_stats_mtl)
export(plot_mtl)
export(pmtl)
export(pwm_mtl)
export(qmtl)
export(quantiles_mtl)
export(rcensor_mtl)
export(rmtl)
export(smtl)
export(ssr_mtl)
export(wls_mtl)

## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 6,
  fig.height = 4
)
library(ModToppLeone)

## ----core_funcs---------------------------------------------------------------
# Density and CDF
dmtl(x = 1.0, alpha = 1.5)
pmtl(q = 1.0, alpha = 1.5)

# Quantile function and Random Generation
qmtl(p = c(0.25, 0.50, 0.75), alpha = 1.5)

set.seed(123)
sample_data <- rmtl(n = 10, alpha = 1.5)
sample_data

# Survival and Hazard Rate Functions
smtl(x = 1.0, alpha = 1.5)
hmtl(x = 1.0, alpha = 1.5)

## ----properties---------------------------------------------------------------
# Mode and Mean
mode_mtl(alpha = 2.5)
mean_mtl(alpha = 1.5)

# Quantiles summary (Median, Skewness, Kurtosis)
quantiles_mtl(alpha = 1.5)

# Mean Deviations about mean and median
meandev_mtl(alpha = 1.5)

# Stress-Strength Reliability P(Y2 < Y1)
ssr_mtl(alpha1 = 2, alpha2 = 3)

## ----classical_fit------------------------------------------------------------
set.seed(42)
sim_data <- rmtl(n = 50, alpha = 2.0)

# Unified estimation wrapper
fit_results <- fit_mtl(x = sim_data, method = "all")
fit_results

## ----bayes_fit----------------------------------------------------------------
# Non-informative prior Bayesian estimation
bayes_res <- bayes_mtl(x = sim_data, prior = "noninformative", loss = "all")
bayes_res$estimates
bayes_res$hpd

## ----censoring----------------------------------------------------------------
# Progressive Type-II Censoring example
R_scheme <- c(2, 0, 1, 0, 2)
prog_sample <- rcensor_mtl(n = 10, alpha = 2.0, scheme = "progressive2", m = 5, R = R_scheme)

mle_censor_mtl(x = prog_sample$x, scheme = "progressive2", R = R_scheme)

## ----datasets-----------------------------------------------------------------
data(dataset_air)
mle_mtl(dataset_air)

#' Classical Estimation Methods for the Modified Topp-Leone Distribution
#'
#' Point and interval estimation of the shape parameter \code{alpha} of the
#' Modified Topp-Leone (MTL) distribution using classical methods: Maximum Likelihood (MLE),
#' Ordinary Least Squares (OLS), Weighted Least Squares (WLS), Cramér-von Mises (CVM),
#' and Maximum Product of Spacings (MPS).
#'
#' @param x Vector of sample observations (\code{x > 0}).
#' @param conf.level Confidence level for interval estimation (default: 0.95).
#' @param method Estimation method: \code{"mle"}, \code{"ols"}, \code{"wls"}, \code{"cvm"}, \code{"mps"}, or \code{"all"}.
#'
#' @return
#' A list or data frame containing point estimate, standard error, asymptotic confidence interval,
#' log-likelihood, AIC, BIC, CAIC, Kolmogorov-Smirnov test statistic, and associated p-value.
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' Cheng, R. C. H., and Amin, N. A. K. (1983). Estimating parameters in continuous univariate
#' distributions with a shifted origin. \emph{Journal of the Royal Statistical Society: Series B}, 45(3), 394-403.
#'
#' Swain, J. J., Venkatraman, S., and Wilson, J. R. (1988). Least-squares estimation of distribution
#' functions in Johnson's translation system. \emph{Journal of Statistical Computation and Simulation}, 29(4), 271-297.
#'
#' @author Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
#'
#' @examples
#' set.seed(123)
#' sample_data <- rmtl(n = 50, alpha = 2.0)
#'
#' # MLE Estimation
#' mle_mtl(x = sample_data)
#'
#' # OLS and WLS Estimation
#' ols_mtl(x = sample_data)
#' wls_mtl(x = sample_data)
#'
#' # CVM and MPS Estimation
#' cvm_mtl(x = sample_data)
#' mps_mtl(x = sample_data)
#'
#' # Fit all classical methods simultaneously
#' fit_mtl(x = sample_data, method = "all")
#'
#' @name classical_mtl
#' @rdname classical_mtl
#' @export
mle_mtl <- function(x, conf.level = 0.95) {
  x <- x[!is.na(x) & x > 0]
  n <- length(x)
  if (n == 0) stop("Vector 'x' must contain positive numeric values.")
  
  # Closed-form formula for MLE (Equation 17)
  denom <- sum(log(((1 + x)^2) / (x * (2 + x))))
  alpha_hat <- n / denom
  
  se <- alpha_hat / sqrt(n)
  
  z_crit <- stats::qnorm(1 - (1 - conf.level) / 2)
  ci_lower <- max(1e-5, alpha_hat - z_crit * se)
  ci_upper <- alpha_hat + z_crit * se
  
  loglik <- sum(dmtl(x, alpha_hat, log = TRUE))
  aic <- 2 * 1 - 2 * loglik
  bic <- log(n) * 1 - 2 * loglik
  caic <- aic + (2 * 1 * (1 + 1)) / (n - 1 - 1)
  
  ks_res <- stats::ks.test(x, "pmtl", alpha = alpha_hat)
  
  res <- list(
    method = "Maximum Likelihood Estimation (MLE)",
    estimate = alpha_hat,
    se = se,
    conf.level = conf.level,
    ci = c(Lower = ci_lower, Upper = ci_upper),
    loglik = loglik,
    AIC = aic,
    BIC = bic,
    CAIC = caic,
    KS_stat = as.numeric(ks_res$statistic),
    p.value = ks_res$p.value
  )
  class(res) <- "mtl_fit"
  return(res)
}

#' @rdname classical_mtl
#' @export
ols_mtl <- function(x) {
  x_sort <- sort(x[!is.na(x) & x > 0])
  n <- length(x_sort)
  if (n == 0) stop("Vector 'x' must contain positive numeric values.")
  
  i_seq <- 1:n
  target_p <- i_seq / (n + 1)
  
  obj_fn <- function(alpha) {
    p_fit <- pmtl(x_sort, alpha)
    sum((p_fit - target_p)^2)
  }
  
  init_alpha <- mle_mtl(x_sort)$estimate
  opt <- stats::optim(par = init_alpha, fn = obj_fn, method = "L-BFGS-B", lower = 1e-5)
  alpha_hat <- opt$par
  
  loglik <- sum(dmtl(x_sort, alpha_hat, log = TRUE))
  aic <- 2 - 2 * loglik
  bic <- log(n) - 2 * loglik
  caic <- aic + (4) / (n - 2)
  
  ks_res <- stats::ks.test(x_sort, "pmtl", alpha = alpha_hat)
  
  res <- list(
    method = "Ordinary Least Squares (OLS)",
    estimate = alpha_hat,
    se = NA,
    loglik = loglik,
    AIC = aic,
    BIC = bic,
    CAIC = caic,
    KS_stat = as.numeric(ks_res$statistic),
    p.value = ks_res$p.value
  )
  class(res) <- "mtl_fit"
  return(res)
}

#' @rdname classical_mtl
#' @export
wls_mtl <- function(x) {
  x_sort <- sort(x[!is.na(x) & x > 0])
  n <- length(x_sort)
  if (n == 0) stop("Vector 'x' must contain positive numeric values.")
  
  i_seq <- 1:n
  target_p <- i_seq / (n + 1)
  weights <- ((n + 1)^2 * (n + 2)) / (i_seq * (n - i_seq + 1))
  
  obj_fn <- function(alpha) {
    p_fit <- pmtl(x_sort, alpha)
    sum(weights * (p_fit - target_p)^2)
  }
  
  init_alpha <- mle_mtl(x_sort)$estimate
  opt <- stats::optim(par = init_alpha, fn = obj_fn, method = "L-BFGS-B", lower = 1e-5)
  alpha_hat <- opt$par
  
  loglik <- sum(dmtl(x_sort, alpha_hat, log = TRUE))
  aic <- 2 - 2 * loglik
  bic <- log(n) - 2 * loglik
  caic <- aic + 4 / (n - 2)
  
  ks_res <- stats::ks.test(x_sort, "pmtl", alpha = alpha_hat)
  
  res <- list(
    method = "Weighted Least Squares (WLS)",
    estimate = alpha_hat,
    se = NA,
    loglik = loglik,
    AIC = aic,
    BIC = bic,
    CAIC = caic,
    KS_stat = as.numeric(ks_res$statistic),
    p.value = ks_res$p.value
  )
  class(res) <- "mtl_fit"
  return(res)
}

#' @rdname classical_mtl
#' @export
cvm_mtl <- function(x) {
  x_sort <- sort(x[!is.na(x) & x > 0])
  n <- length(x_sort)
  if (n == 0) stop("Vector 'x' must contain positive numeric values.")
  
  i_seq <- 1:n
  target_p <- (2 * i_seq - 1) / (2 * n)
  
  obj_fn <- function(alpha) {
    p_fit <- pmtl(x_sort, alpha)
    (1 / (12 * n)) + sum((p_fit - target_p)^2)
  }
  
  init_alpha <- mle_mtl(x_sort)$estimate
  opt <- stats::optim(par = init_alpha, fn = obj_fn, method = "L-BFGS-B", lower = 1e-5)
  alpha_hat <- opt$par
  
  loglik <- sum(dmtl(x_sort, alpha_hat, log = TRUE))
  aic <- 2 - 2 * loglik
  bic <- log(n) - 2 * loglik
  caic <- aic + 4 / (n - 2)
  
  ks_res <- stats::ks.test(x_sort, "pmtl", alpha = alpha_hat)
  
  res <- list(
    method = "Cramer-von Mises (CVM)",
    estimate = alpha_hat,
    se = NA,
    loglik = loglik,
    AIC = aic,
    BIC = bic,
    CAIC = caic,
    KS_stat = as.numeric(ks_res$statistic),
    p.value = ks_res$p.value
  )
  class(res) <- "mtl_fit"
  return(res)
}

#' @rdname classical_mtl
#' @export
mps_mtl <- function(x) {
  x_sort <- sort(x[!is.na(x) & x > 0])
  n <- length(x_sort)
  if (n == 0) stop("Vector 'x' must contain positive numeric values.")
  
  obj_fn <- function(alpha) {
    cdf_vals <- c(0, pmtl(x_sort, alpha), 1)
    spacings <- diff(cdf_vals)
    spacings <- pmax(spacings, 1e-12)
    -mean(log(spacings))
  }
  
  init_alpha <- mle_mtl(x_sort)$estimate
  opt <- stats::optim(par = init_alpha, fn = obj_fn, method = "L-BFGS-B", lower = 1e-5)
  alpha_hat <- opt$par
  
  loglik <- sum(dmtl(x_sort, alpha_hat, log = TRUE))
  aic <- 2 - 2 * loglik
  bic <- log(n) - 2 * loglik
  caic <- aic + 4 / (n - 2)
  
  ks_res <- stats::ks.test(x_sort, "pmtl", alpha = alpha_hat)
  
  res <- list(
    method = "Maximum Product of Spacings (MPS)",
    estimate = alpha_hat,
    se = NA,
    loglik = loglik,
    AIC = aic,
    BIC = bic,
    CAIC = caic,
    KS_stat = as.numeric(ks_res$statistic),
    p.value = ks_res$p.value
  )
  class(res) <- "mtl_fit"
  return(res)
}

#' @rdname classical_mtl
#' @export
fit_mtl <- function(x, method = c("mle", "ols", "wls", "cvm", "mps", "all"), conf.level = 0.95) {
  method <- match.arg(method)
  
  if (method == "mle") {
    return(mle_mtl(x = x, conf.level = conf.level))
  } else if (method == "ols") {
    return(ols_mtl(x = x))
  } else if (method == "wls") {
    return(wls_mtl(x = x))
  } else if (method == "cvm") {
    return(cvm_mtl(x = x))
  } else if (method == "mps") {
    return(mps_mtl(x = x))
  } else if (method == "all") {
    res_mle <- mle_mtl(x = x, conf.level = conf.level)
    res_ols <- ols_mtl(x = x)
    res_wls <- wls_mtl(x = x)
    res_cvm <- cvm_mtl(x = x)
    res_mps <- mps_mtl(x = x)
    
    df <- data.frame(
      Method = c("MLE", "OLS", "WLS", "CVM", "MPS"),
      Estimate = c(res_mle$estimate, res_ols$estimate, res_wls$estimate, res_cvm$estimate, res_mps$estimate),
      SE = c(res_mle$se, res_ols$se, res_wls$se, res_cvm$se, res_mps$se),
      LogLik = c(res_mle$loglik, res_ols$loglik, res_wls$loglik, res_cvm$loglik, res_mps$loglik),
      AIC = c(res_mle$AIC, res_ols$AIC, res_wls$AIC, res_cvm$AIC, res_mps$AIC),
      BIC = c(res_mle$BIC, res_ols$BIC, res_wls$BIC, res_cvm$BIC, res_mps$BIC),
      CAIC = c(res_mle$CAIC, res_ols$CAIC, res_wls$CAIC, res_cvm$CAIC, res_mps$CAIC),
      KS_stat = c(res_mle$KS_stat, res_ols$KS_stat, res_wls$KS_stat, res_cvm$KS_stat, res_mps$KS_stat),
      p.value = c(res_mle$p.value, res_ols$p.value, res_wls$p.value, res_cvm$p.value, res_mps$p.value)
    )
    return(df)
  }
}

#' Statistical Properties of the Modified Topp-Leone Distribution
#'
#' Functions to calculate various statistical properties of the Modified Topp-Leone (MTL)
#' distribution including mode, mean, quantiles, mean deviations, inequality measures,
#' mean residual life, mean past life, probability-weighted moments, entropies,
#' stress-strength reliability, and order statistics.
#'
#' @param alpha Shape parameter of the MTL distribution (\code{alpha > 0}).
#' @param alpha1,alpha2 Shape parameters for two independent MTL variables in stress-strength reliability.
#' @param r Order of the raw moment or probability-weighted moment.
#' @param s Parameter for probability-weighted moment.
#' @param y Evaluation point for residual life, past life, inequality curves, or order statistics.
#' @param n Sample size for order statistics.
#' @param u Index of the order statistic (\code{1 <= u <= n}).
#' @param n_terms Number of terms to use in series expansions (default: 100).
#' @param type Type of entropy (\code{"renyi"}, \code{"shannon"}, or \code{"omega"}) or order statistics output (\code{"pdf"} or \code{"cdf"}).
#' @param gamma Order parameter for Rényi or \eqn{\omega}-entropy (\code{gamma > 0, gamma != 1}).
#'
#' @return
#' Numeric scalar or vector corresponding to the calculated statistical property:
#' \itemize{
#'   \item \code{mode_mtl}: Mode of the MTL distribution.
#'   \item \code{mean_mtl}: Mean of the MTL distribution.
#'   \item \code{moments_mtl}: $r$-th raw moment (finite for $r = 1$).
#'   \item \code{quantiles_mtl}: Named vector of quantiles, median, skewness, and kurtosis.
#'   \item \code{meandev_mtl}: Mean deviation about mean and median.
#'   \item \code{inequality_mtl}: Lorenz, Bonferroni, and Zenga inequality measures.
#'   \item \code{mrl_mtl}: Mean residual life function.
#'   \item \code{mpl_mtl}: Mean past life (expected inactivity time) function.
#'   \item \code{pwm_mtl}: Probability-weighted moment \eqn{\mu_{r,s}}.
#'   \item \code{entropy_mtl}: Specified entropy measure.
#'   \item \code{ssr_mtl}: Stress-strength reliability \eqn{R = P[Y_2 < Y_1]}.
#'   \item \code{order_stats_mtl}: Density or CDF of the $u$-th order statistic.
#' }
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' @author Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
#'
#' @examples
#' # Mode and Mean
#' mode_mtl(alpha = 2.5)
#' mean_mtl(alpha = 1.5)
#'
#' # Quantiles summary
#' quantiles_mtl(alpha = 1.5)
#'
#' # Mean deviations
#' meandev_mtl(alpha = 1.5)
#'
#' # Inequality measures at y = 1
#' inequality_mtl(y = 1, alpha = 1.5)
#'
#' # Mean residual life and past life
#' mrl_mtl(y = 1, alpha = 1.5)
#' mpl_mtl(y = 1, alpha = 1.5)
#'
#' # Entropies
#' entropy_mtl(alpha = 1.5, type = "shannon")
#' entropy_mtl(alpha = 1.5, type = "renyi", gamma = 0.5)
#'
#' # Stress-Strength Reliability
#' ssr_mtl(alpha1 = 2, alpha2 = 3)
#'
#' # Order statistics density for median in n = 5 sample
#' order_stats_mtl(y = 1, alpha = 1.5, n = 5, u = 3, type = "pdf")
#'
#' @name properties_mtl
#' @rdname properties_mtl
#' @export
mode_mtl <- function(alpha) {
  if (alpha <= 1) {
    return(0)
  } else {
    mode_val <- sqrt(1 + (1 / 3) * sqrt(6 * alpha + 3)) - 1
    return(mode_val)
  }
}

#' @rdname properties_mtl
#' @export
mean_mtl <- function(alpha, n_terms = 100) {
  if (alpha <= 0) stop("'alpha' must be positive.")
  
  res <- tryCatch({
    stats::integrate(function(y) y * dmtl(y, alpha), lower = 0, upper = Inf)$value
  }, error = function(e) {
    j <- 0:(n_terms - 1)
    coefs <- choose(alpha - 1, j)
    beta_vals <- beta(alpha + 1, j + 1)
    2 * alpha * sum(coefs * beta_vals)
  })
  
  return(res)
}

#' @rdname properties_mtl
#' @export
moments_mtl <- function(r, alpha, n_terms = 100) {
  if (r == 1) {
    return(mean_mtl(alpha, n_terms = n_terms))
  } else if (r >= 2) {
    warning("MTL distribution does not have finite moments of order r >= 2.")
    return(Inf)
  } else {
    stop("Order 'r' must be a positive integer.")
  }
}

#' @rdname properties_mtl
#' @export
quantiles_mtl <- function(alpha) {
  q1 <- qmtl(0.25, alpha)
  q2 <- qmtl(0.50, alpha)
  q3 <- qmtl(0.75, alpha)
  q18 <- qmtl(1 / 8, alpha)
  q38 <- qmtl(3 / 8, alpha)
  q58 <- qmtl(5 / 8, alpha)
  q78 <- qmtl(7 / 8, alpha)
  
  sk <- (q3 + q1 - 2 * q2) / (q3 - q1)
  ku <- (q78 - q58 + q38 - q18) / (q3 - q1)
  m_val <- mode_mtl(alpha)
  
  res <- c(
    Q1 = q1,
    Median = q2,
    Q3 = q3,
    Mode = m_val,
    Skewness = sk,
    Kurtosis = ku
  )
  return(res)
}

#' @rdname properties_mtl
#' @export
meandev_mtl <- function(alpha) {
  mu <- mean_mtl(alpha)
  med <- qmtl(0.5, alpha)
  
  i_mu <- stats::integrate(function(y) y * dmtl(y, alpha), lower = 0, upper = mu)$value
  i_med <- stats::integrate(function(y) y * dmtl(y, alpha), lower = 0, upper = med)$value
  
  f_mu <- pmtl(mu, alpha)
  f_med <- pmtl(med, alpha)
  
  md_mean <- 2 * (mu * f_mu - i_mu)
  md_median <- 2 * (med * f_med - i_med)
  
  return(c(MD_mean = md_mean, MD_median = md_median))
}

#' @rdname properties_mtl
#' @export
inequality_mtl <- function(y, alpha) {
  mu <- mean_mtl(alpha)
  fy <- pmtl(y, alpha)
  sy <- smtl(y, alpha)
  
  i_lower <- stats::integrate(function(z) z * dmtl(z, alpha), lower = 0, upper = y)$value
  mu_minus <- i_lower / fy
  
  i_upper <- stats::integrate(function(z) z * dmtl(z, alpha), lower = y, upper = Inf)$value
  mu_plus <- i_upper / sy
  
  lorenz <- i_lower / mu
  bonferroni <- mu_minus / mu
  zenga <- 1 - (mu_minus / mu_plus)
  
  return(c(Lorenz = lorenz, Bonferroni = bonferroni, Zenga = zenga))
}

#' @rdname properties_mtl
#' @export
mrl_mtl <- function(y, alpha) {
  sy <- smtl(y, alpha)
  if (sy <= 0) return(0)
  
  i_val <- stats::integrate(function(z) smtl(z, alpha), lower = y, upper = Inf)$value
  return(i_val / sy)
}

#' @rdname properties_mtl
#' @export
mpl_mtl <- function(y, alpha) {
  fy <- pmtl(y, alpha)
  if (fy <= 0) return(0)
  
  i_val <- stats::integrate(function(z) pmtl(z, alpha), lower = 0, upper = y)$value
  return(i_val / fy)
}

#' @rdname properties_mtl
#' @export
pwm_mtl <- function(r, s, alpha) {
  res <- stats::integrate(function(y) (y^r) * (pmtl(y, alpha)^s) * dmtl(y, alpha), lower = 0, upper = Inf)$value
  return(res)
}

#' @rdname properties_mtl
#' @export
entropy_mtl <- function(alpha, type = c("shannon", "renyi", "omega"), gamma = 0.5) {
  type <- match.arg(type)
  
  if (type == "shannon") {
    res <- -stats::integrate(function(y) dmtl(y, alpha) * dmtl(y, alpha, log = TRUE), lower = 0, upper = Inf)$value
    return(res)
  } else if (type == "renyi") {
    if (gamma <= 0 || gamma == 1) stop("'gamma' must be positive and != 1 for Renyi entropy.")
    integral_val <- stats::integrate(function(y) dmtl(y, alpha)^gamma, lower = 0, upper = Inf)$value
    res <- (1 / (1 - gamma)) * log(integral_val)
    return(res)
  } else if (type == "omega") {
    if (gamma <= 0 || gamma == 1) stop("'gamma' must be positive and != 1 for omega entropy.")
    integral_val <- stats::integrate(function(y) dmtl(y, alpha)^gamma, lower = 0, upper = Inf)$value
    # Tsallis / Omega entropy definition: H_omega(Y) = (1 / (gamma - 1)) * (1 - integral_val)
    res <- (1 / (1 - gamma)) * (integral_val - 1)
    return(res)
  }
}

#' @rdname properties_mtl
#' @export
ssr_mtl <- function(alpha1, alpha2) {
  if (alpha1 <= 0 || alpha2 <= 0) stop("Shape parameters 'alpha1' and 'alpha2' must be positive.")
  return(alpha1 / (alpha1 + alpha2))
}

#' @rdname properties_mtl
#' @export
order_stats_mtl <- function(y, alpha, n, u, type = c("pdf", "cdf")) {
  type <- match.arg(type)
  if (u < 1 || u > n) stop("'u' must be between 1 and 'n'.")
  
  fy <- dmtl(y, alpha)
  Fy <- pmtl(y, alpha)
  Sy <- 1 - Fy
  
  if (type == "pdf") {
    c_factor <- factorial(n) / (factorial(u - 1) * factorial(n - u))
    res <- c_factor * fy * (Fy^(u - 1)) * (Sy^(n - u))
    return(res)
  } else {
    res <- stats::pbeta(Fy, u, n - u + 1)
    return(res)
  }
}

test_that("dmtl, pmtl, qmtl, rmtl, smtl, hmtl work correctly", {
  alpha <- 1.5
  
  # PDF integrates to 1
  integral_val <- stats::integrate(function(x) dmtl(x, alpha), lower = 0, upper = Inf)$value
  expect_equal(integral_val, 1, tolerance = 1e-4)
  
  # CDF and Quantile inverse property
  p_seq <- c(0.1, 0.25, 0.5, 0.75, 0.9)
  q_vals <- qmtl(p_seq, alpha)
  p_recalc <- pmtl(q_vals, alpha)
  expect_equal(p_seq, p_recalc, tolerance = 1e-5)
  
  # Survival function
  expect_equal(smtl(q_vals, alpha), 1 - p_seq, tolerance = 1e-5)
  
  # Hazard function non-negative and finite
  hrf_val <- hmtl(x = 1, alpha = alpha)
  expect_true(is.numeric(hrf_val) && hrf_val > 0 && is.finite(hrf_val))
  
  # Random generation
  set.seed(42)
  rnd <- rmtl(n = 100, alpha = alpha)
  expect_equal(length(rnd), 100)
  expect_true(all(rnd > 0))
  expect_false(any(is.na(rnd)))
  expect_false(any(is.nan(rnd)))
})

test_that("Classical estimation functions work without warnings, NAs, or NaNs", {
  set.seed(123)
  true_alpha <- 2.0
  x_sample <- rmtl(n = 100, alpha = true_alpha)
  
  # MLE
  res_mle <- mle_mtl(x = x_sample)
  expect_equal(res_mle$estimate, true_alpha, tolerance = 0.3)
  expect_false(is.na(res_mle$estimate))
  expect_false(is.nan(res_mle$estimate))
  
  # OLS, WLS, CVM, MPS
  res_ols <- ols_mtl(x = x_sample)
  expect_true(res_ols$estimate > 0)
  
  res_wls <- wls_mtl(x = x_sample)
  expect_true(res_wls$estimate > 0)
  
  res_cvm <- cvm_mtl(x = x_sample)
  expect_true(res_cvm$estimate > 0)
  
  res_mps <- mps_mtl(x = x_sample)
  expect_true(res_mps$estimate > 0)
  
  # Fit all
  df_all <- fit_mtl(x = x_sample, method = "all")
  expect_equal(nrow(df_all), 5)
  expect_false(any(is.na(df_all$Estimate)))
})

test_that("Bayesian estimation functions work properly", {
  set.seed(123)
  x_sample <- rmtl(n = 50, alpha = 2.0)
  
  res_bayes <- bayes_mtl(x = x_sample, prior = "noninformative", loss = "all", n.draws = 2000, burn.in = 500)
  expect_true(res_bayes$estimates["SELF"] > 0)
  expect_true(res_bayes$hpd["Lower"] < res_bayes$hpd["Upper"])
  expect_false(any(is.na(res_bayes$estimates)))
})

test_that("Censoring functions operate without errors", {
  set.seed(123)
  alpha_val <- 2.0
  
  # Random censoring
  c_rand <- rcensor_mtl(n = 30, alpha = alpha_val, scheme = "random")
  mle_rand <- mle_censor_mtl(x = c_rand$x, status = c_rand$status, scheme = "random")
  expect_true(mle_rand$estimate > 0)
  
  # Type-I censoring
  c_t1 <- rcensor_mtl(n = 30, alpha = alpha_val, scheme = "type1", T_censor = 1.0)
  mle_t1 <- mle_censor_mtl(x = c_t1$x, status = c_t1$status, scheme = "type1")
  expect_true(mle_t1$estimate > 0)
  
  # Progressive Type-II censoring
  R_sch <- c(2, 0, 1, 0, 2)
  c_prog <- rcensor_mtl(n = 10, alpha = alpha_val, scheme = "progressive2", m = 5, R = R_sch)
  mle_prog <- mle_censor_mtl(x = c_prog$x, scheme = "progressive2", R = R_sch)
  expect_true(mle_prog$estimate > 0)
})

test_that("Statistical properties functions return expected outputs", {
  alpha_val <- 2.5
  
  expect_true(mode_mtl(alpha = alpha_val) > 0)
  expect_true(mean_mtl(alpha = alpha_val) > 0)
  
  q_sum <- quantiles_mtl(alpha = alpha_val)
  expect_true(q_sum["Median"] > 0)
  
  md <- meandev_mtl(alpha = alpha_val)
  expect_true(md["MD_mean"] > 0)
  
  ineq <- inequality_mtl(y = 1, alpha = alpha_val)
  expect_true(ineq["Lorenz"] > 0 && ineq["Lorenz"] <= 1)
  
  expect_true(mrl_mtl(y = 1, alpha = alpha_val) > 0)
  expect_true(mpl_mtl(y = 1, alpha = alpha_val) > 0)
  
  expect_true(ssr_mtl(alpha1 = 2, alpha2 = 3) == 0.4)
  
  os <- order_stats_mtl(y = 1, alpha = alpha_val, n = 5, u = 3, type = "pdf")
  expect_true(os > 0)
})

#' Bayesian Estimation for the Modified Topp-Leone Distribution
#'
#' Estimates the shape parameter \code{alpha} of the Modified Topp-Leone (MTL) distribution
#' under informative (Gamma) and non-informative priors using symmetric (SELF) and asymmetric
#' (ELF, PLF, GELF) loss functions, along with Chen-Shao Highest Posterior Density (HPD) intervals.
#'
#' @param x Vector of sample observations (\code{x > 0}).
#' @param prior Type of prior distribution: \code{"informative"} (Gamma(a, b)) or \code{"noninformative"} (\code{a = 0, b = 0}).
#' @param a Shape parameter for Gamma prior (hyperparameter \code{a > 0}).
#' @param b Rate parameter for Gamma prior (hyperparameter \code{b > 0}).
#' @param loss Loss function: \code{"self"} (Squared Error Loss), \code{"elf"} (Entropy Loss),
#'   \code{"plf"} (Precautionary Loss), \code{"gelf"} (Generalized Entropy Loss), or \code{"all"}.
#' @param delta Constant for Generalized Entropy Loss Function (\code{delta != 0}). Default is 1.
#' @param n.draws Number of MCMC iterations (default: 10000).
#' @param burn.in Number of initial draws to discard as burn-in (default: 1000).
#' @param thin Thinning interval for MCMC chain (default: 1).
#' @param conf.level Credible level for HPD interval estimation (default: 0.95).
#'
#' @return
#' A list containing point estimates under specified loss functions, posterior standard error (PSE),
#' posterior summary statistics, MCMC sample draws, and the 100*(1 - alpha)\% HPD interval.
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' Chen, M. H., and Shao, Q. M. (1999). Monte Carlo estimation of Bayesian credible and HPD intervals.
#' \emph{Journal of Computational and Graphical Statistics}, 8(1), 69-92.
#'
#' Calabria, R., and Pulcini, G. (1996). Point estimation under asymmetric loss functions for left-truncated
#' exponential samples. \emph{Communications in Statistics - Theory and Methods}, 25(3), 585-600.
#'
#' @author Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
#'
#' @examples
#' set.seed(123)
#' sample_data <- rmtl(n = 30, alpha = 2.5)
#'
#' # Bayesian Estimation under Non-informative Prior
#' bayes_mtl(x = sample_data, prior = "noninformative", loss = "all")
#'
#' # Bayesian Estimation under Informative Prior (a = 2, b = 1)
#' bayes_mtl(x = sample_data, prior = "informative", a = 2, b = 1, loss = "self")
#'
#' @name bayes_mtl
#' @rdname bayes_mtl
#' @export
bayes_mtl <- function(x, prior = c("informative", "noninformative"),
                      a = 1, b = 1, loss = c("self", "elf", "plf", "gelf", "all"),
                      delta = 1, n.draws = 10000, burn.in = 1000, thin = 1,
                      conf.level = 0.95) {
  prior <- match.arg(prior)
  loss <- match.arg(loss)
  
  x <- x[!is.na(x) & x > 0]
  n <- length(x)
  if (n == 0) stop("Vector 'x' must contain positive numeric values.")
  
  if (prior == "noninformative") {
    shape_post <- n
    rate_post <- sum(log(((1 + x)^2) / (x * (2 + x))))
  } else {
    if (a <= 0 || b <= 0) stop("Hyperparameters 'a' and 'b' must be positive for informative prior.")
    shape_post <- n + b
    rate_post <- a + sum(log(((1 + x)^2) / (x * (2 + x))))
  }
  
  # Generate exact posterior draws from Gamma distribution
  raw_draws <- stats::rgamma(n.draws, shape = shape_post, rate = rate_post)
  
  # Burn-in and Thinning
  post_draws <- raw_draws[(burn.in + 1):n.draws]
  if (thin > 1) {
    post_draws <- post_draws[seq(1, length(post_draws), by = thin)]
  }
  
  # Point Estimates under Loss Functions
  hat_self <- mean(post_draws)
  hat_elf <- 1 / mean(1 / post_draws)
  hat_plf <- sqrt(mean(post_draws^2))
  hat_gelf <- (mean(post_draws^(-delta)))^(-1 / delta)
  
  pse <- stats::sd(post_draws)
  
  # Chen-Shao HPD Interval calculation
  sorted_draws <- sort(post_draws)
  m_len <- length(sorted_draws)
  k_len <- floor(conf.level * m_len)
  
  widths <- sorted_draws[(1 + k_len):m_len] - sorted_draws[1:(m_len - k_len)]
  min_idx <- which.min(widths)
  hpd_lower <- sorted_draws[min_idx]
  hpd_upper <- sorted_draws[min_idx + k_len]
  
  loss_estimates <- c(
    SELF = hat_self,
    ELF = hat_elf,
    PLF = hat_plf,
    GELF = hat_gelf
  )
  
  if (loss != "all") {
    sel_name <- toupper(loss)
    point_est <- loss_estimates[sel_name]
  } else {
    point_est <- loss_estimates
  }
  
  res <- list(
    method = paste("Bayesian Estimation under", prior, "prior"),
    prior = prior,
    hyperparams = if (prior == "informative") c(a = a, b = b) else c(a = 0, b = 0),
    estimates = point_est,
    PSE = pse,
    conf.level = conf.level,
    hpd = c(Lower = hpd_lower, Upper = hpd_upper),
    posterior_summary = c(
      Mean = mean(post_draws),
      Median = stats::median(post_draws),
      SD = pse,
      Q2.5 = stats::quantile(post_draws, 0.025),
      Q97.5 = stats::quantile(post_draws, 0.975)
    ),
    draws = post_draws
  )
  class(res) <- "mtl_bayes"
  return(res)
}

#' Real Datasets used in Modified Topp-Leone Research Paper
#'
#' Three real-world datasets examined in Singh et al. (2025) to illustrate the flexibility and
#' applicability of the Modified Topp-Leone distribution.
#'
#' @format Numeric vectors containing positive observations:
#' \describe{
#'   \item{dataset_air}{Number of successive failures for the air conditioning system of each member in a fleet of 13 Boeing 720 jet airplanes (divided by 100 for fitting convenience).}
#'   \item{dataset_covid_india}{Daily new COVID-19 cases in India from 16 March 2021 to 16 April 2021 (divided by 10,000).}
#'   \item{dataset_covid_france}{Daily new COVID-19 cases in France from 5 August 2020 to 5 November 2020 (divided by 10,000).}
#' }
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' Cordeiro, G. M., and Lemonte, A. J. (2011). The beta-Birnbaum-Saunders distribution:
#' An improved distribution for fatigue life modelling. \emph{Computational Statistics & Data Analysis}, 55(3), 1445-1461.
#'
#' @name real_datasets
#' @docType data
#' @keywords datasets
#' @examples
#' data(dataset_air)
#' mle_mtl(dataset_air)
#'
#' data(dataset_covid_india)
#' fit_mtl(dataset_covid_india, method = "all")
#'
#' data(dataset_covid_france)
#' bayes_mtl(dataset_covid_france, prior = "noninformative")
"dataset_air"

#' @rdname real_datasets
"dataset_covid_india"

#' @rdname real_datasets
"dataset_covid_france"

#' Diagnostic and Visualization Plots for the Modified Topp-Leone Distribution
#'
#' Plot probability density function (PDF), cumulative distribution function (CDF),
#' survival function (SF), or hazard rate function (HRF) of the Modified Topp-Leone (MTL)
#' distribution for specified values of \code{alpha}.
#'
#' @param alpha Vector of shape parameter values (\code{alpha > 0}).
#' @param type Type of plot: \code{"pdf"}, \code{"cdf"}, \code{"sf"}, or \code{"hrf"}.
#' @param x_max Maximum value of x on the horizontal axis (default: 10).
#' @param n_points Number of evaluation points along the x-axis (default: 500).
#'
#' @return
#' No return value, called for side effects (produces a plot).
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' @author Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
#'
#' @examples
#' # Plot PDF for various values of alpha
#' plot_mtl(alpha = c(0.5, 1.5, 3.0, 10.0), type = "pdf", x_max = 5)
#'
#' # Plot HRF for various values of alpha
#' plot_mtl(alpha = c(0.5, 1.5, 3.0, 10.0), type = "hrf", x_max = 5)
#'
#' @name plot_mtl
#' @rdname plot_mtl
#' @export
plot_mtl <- function(alpha = c(0.5, 1.5, 3.0, 10.0),
                     type = c("pdf", "cdf", "sf", "hrf"),
                     x_max = 10, n_points = 500) {
  type <- match.arg(type)
  x_seq <- seq(0.01, x_max, length.out = n_points)
  
  colors <- c("#E41A1C", "#377EB8", "#4DAF4A", "#984EA3", "#FF7F00", "#FFFF33")
  col_palette <- rep(colors, length.out = length(alpha))
  
  if (type == "pdf") {
    y_mat <- sapply(alpha, function(a) dmtl(x_seq, a))
    y_lim <- c(0, min(3, max(y_mat, na.rm = TRUE)))
    main_title <- "Modified Topp-Leone Density Function (PDF)"
    y_label <- "Density f(y)"
  } else if (type == "cdf") {
    y_mat <- sapply(alpha, function(a) pmtl(x_seq, a))
    y_lim <- c(0, 1)
    main_title <- "Modified Topp-Leone Distribution Function (CDF)"
    y_label <- "CDF F(y)"
  } else if (type == "sf") {
    y_mat <- sapply(alpha, function(a) smtl(x_seq, a))
    y_lim <- c(0, 1)
    main_title <- "Modified Topp-Leone Survival Function (SF)"
    y_label <- "Survival S(y)"
  } else if (type == "hrf") {
    y_mat <- sapply(alpha, function(a) hmtl(x_seq, a))
    y_lim <- c(0, min(3, max(y_mat[is.finite(y_mat)], na.rm = TRUE)))
    main_title <- "Modified Topp-Leone Hazard Rate Function (HRF)"
    y_label <- "Hazard Rate r(y)"
  }
  
  graphics::plot(x_seq, y_mat[, 1], type = "l", col = col_palette[1], lwd = 2,
                 ylim = y_lim, xlab = "y", ylab = y_label, main = main_title)
  
  if (length(alpha) > 1) {
    for (j in 2:length(alpha)) {
      graphics::lines(x_seq, y_mat[, j], col = col_palette[j], lwd = 2)
    }
  }
  
  legend_labels <- paste("alpha =", alpha)
  graphics::legend("topright", legend = legend_labels, col = col_palette, lwd = 2, bty = "n")
  
  invisible(NULL)
}

#' Censoring Schemes and Estimation for the Modified Topp-Leone Distribution
#'
#' Functions to generate random samples and estimate parameters of the Modified Topp-Leone (MTL)
#' distribution under various censoring schemes: Random Right Censoring, Type-I Censoring,
#' Type-II Censoring, and Progressive Type-II Censoring.
#'
#' @param n Total initial sample size.
#' @param alpha Shape parameter of the MTL distribution (\code{alpha > 0}).
#' @param scheme Type of censoring scheme: \code{"random"}, \code{"type1"}, \code{"type2"}, or \code{"progressive2"}.
#' @param T_censor Fixed censoring time for Type-I censoring (\code{T_censor > 0}).
#' @param m Number of observed failures for Type-II or Progressive Type-II censoring (\code{1 <= m <= n}).
#' @param R Vector of removal counts for Progressive Type-II censoring of length \code{m} such that \code{sum(R) == n - m}.
#' @param censor_rate Rate parameter for exponential censoring distribution in random censoring.
#' @param x Vector of observed failure/censoring times.
#' @param status Vector of censoring indicators (1 = observed failure, 0 = censored).
#' @param conf.level Confidence level for interval estimation (default: 0.95).
#'
#' @return
#' \code{rcensor_mtl} returns a list containing observed times (\code{x}), censoring status (\code{status}),
#' censoring scheme info, and parameter settings.
#' \code{mle_censor_mtl} returns a list containing point estimate (\code{estimate}), standard error (\code{se}),
#' asymptotic confidence interval (\code{ci}), and log-likelihood value under censoring.
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' Balakrishnan, N., and Aggarwala, R. (2000). \emph{Progressive Censoring: Theory, Methods, and Applications}.
#' Birkhäuser, Boston.
#'
#' @author Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
#'
#' @examples
#' set.seed(123)
#' # 1. Random Right Censoring
#' rand_cens <- rcensor_mtl(n = 30, alpha = 2.0, scheme = "random", censor_rate = 0.5)
#' mle_censor_mtl(x = rand_cens$x, status = rand_cens$status, scheme = "random")
#'
#' # 2. Type-I Censoring
#' t1_cens <- rcensor_mtl(n = 30, alpha = 2.0, scheme = "type1", T_censor = 1.5)
#' mle_censor_mtl(x = t1_cens$x, status = t1_cens$status, scheme = "type1")
#'
#' # 3. Type-II Censoring
#' t2_cens <- rcensor_mtl(n = 30, alpha = 2.0, scheme = "type2", m = 20)
#' mle_censor_mtl(x = t2_cens$x, status = t2_cens$status, scheme = "type2")
#'
#' # 4. Progressive Type-II Censoring
#' R_scheme <- c(2, 0, 1, 0, 2, 0, 1, 0, 2, 2)
#' prog_cens <- rcensor_mtl(n = 20, alpha = 2.0, scheme = "progressive2", m = 10, R = R_scheme)
#' mle_censor_mtl(x = prog_cens$x, scheme = "progressive2", R = R_scheme)
#'
#' @name censoring_mtl
#' @rdname censoring_mtl
#' @export
rcensor_mtl <- function(n, alpha, scheme = c("random", "type1", "type2", "progressive2"),
                        T_censor = NULL, m = NULL, R = NULL, censor_rate = 0.5) {
  scheme <- match.arg(scheme)
  if (n <= 0) stop("'n' must be a positive integer.")
  if (alpha <= 0) stop("'alpha' must be positive.")
  
  if (scheme == "random") {
    y <- rmtl(n = n, alpha = alpha)
    c_times <- stats::rexp(n = n, rate = censor_rate)
    x_obs <- pmin(y, c_times)
    status <- as.numeric(y <= c_times)
    
    res <- list(x = x_obs, status = status, scheme = "Random Right Censoring", alpha = alpha)
  } else if (scheme == "type1") {
    if (is.null(T_censor) || T_censor <= 0) stop("'T_censor' must be specified and > 0 for Type-I censoring.")
    y <- rmtl(n = n, alpha = alpha)
    x_obs <- pmin(y, T_censor)
    status <- as.numeric(y <= T_censor)
    
    res <- list(x = x_obs, status = status, T_censor = T_censor, scheme = "Type-I Censoring", alpha = alpha)
  } else if (scheme == "type2") {
    if (is.null(m) || m <= 0 || m > n) stop("'m' must satisfy 1 <= m <= n for Type-II censoring.")
    y <- rmtl(n = n, alpha = alpha)
    y_sort <- sort(y)
    x_obs <- y_sort[1:m]
    status <- rep(1, m)
    
    res <- list(x = x_obs, status = status, m = m, scheme = "Type-II Censoring", alpha = alpha)
  } else if (scheme == "progressive2") {
    if (is.null(m) || m <= 0 || m > n) stop("'m' must satisfy 1 <= m <= n for Progressive Type-II censoring.")
    if (is.null(R) || length(R) != m || sum(R) != (n - m)) {
      stop(paste0("'R' must be a vector of length m = ", m, " summing to n - m = ", n - m, "."))
    }
    
    # Balakrishnan & Aggarwala (2000) algorithm for Progressive Type-II sample generation
    u <- stats::runif(m)
    v <- numeric(m)
    for (i in 1:m) {
      sum_R <- if (i == 1) sum(R) else sum(R[m:(m - i + 2)])
      v[i] <- u[i]^(1 / (i + sum_R))
    }
    
    w <- numeric(m)
    for (i in 1:m) {
      w[i] <- 1 - prod(v[m:(m - i + 1)])
    }
    
    x_obs <- qmtl(p = w, alpha = alpha)
    status <- rep(1, m)
    
    res <- list(x = x_obs, status = status, m = m, R = R, scheme = "Progressive Type-II Censoring", alpha = alpha)
  }
  
  class(res) <- "mtl_censor_sample"
  return(res)
}

#' @rdname censoring_mtl
#' @export
mle_censor_mtl <- function(x, status = NULL, scheme = c("random", "type1", "type2", "progressive2"),
                           R = NULL, conf.level = 0.95) {
  scheme <- match.arg(scheme)
  
  if (scheme %in% c("random", "type1")) {
    if (is.null(status)) stop("'status' vector is required for random or type1 censoring.")
    
    loglik_fn <- function(alpha) {
      if (alpha <= 0) return(1e10)
      ll_event <- sum(dmtl(x[status == 1], alpha, log = TRUE))
      ll_censor <- sum(smtl(x[status == 0], alpha, log.p = TRUE))
      -(ll_event + ll_censor)
    }
  } else if (scheme == "type2") {
    m <- length(x)
    y_m <- max(x)
    
    loglik_fn <- function(alpha) {
      if (alpha <= 0) return(1e10)
      ll_obs <- sum(dmtl(x, alpha, log = TRUE))
      # Remaining (n - m) items censored at y_m, but for standard Type-II log-likelihood over observed:
      -(ll_obs)
    }
  } else if (scheme == "progressive2") {
    m <- length(x)
    if (is.null(R) || length(R) != m) stop("'R' scheme must match the length of observed failures 'x'.")
    
    loglik_fn <- function(alpha) {
      if (alpha <= 0) return(1e10)
      ll_obs <- sum(dmtl(x, alpha, log = TRUE))
      ll_rem <- sum(R * smtl(x, alpha, log.p = TRUE))
      -(ll_obs + ll_rem)
    }
  }
  
  init_alpha <- 1.0
  opt <- stats::optim(par = init_alpha, fn = loglik_fn, method = "L-BFGS-B", lower = 1e-5, hessian = TRUE)
  alpha_hat <- opt$par
  
  # Standard Error via Hessian
  se <- tryCatch({
    sqrt(1 / as.numeric(opt$hessian))
  }, error = function(e) NA)
  
  z_crit <- stats::qnorm(1 - (1 - conf.level) / 2)
  ci_lower <- if (!is.na(se)) max(1e-5, alpha_hat - z_crit * se) else NA
  ci_upper <- if (!is.na(se)) alpha_hat + z_crit * se else NA
  
  res <- list(
    method = paste("MLE under", scheme, "censoring"),
    estimate = alpha_hat,
    se = se,
    conf.level = conf.level,
    ci = c(Lower = ci_lower, Upper = ci_upper),
    loglik = -opt$value
  )
  class(res) <- "mtl_censor_fit"
  return(res)
}

#' The Modified Topp-Leone Distribution
#'
#' Density, distribution function, quantile function, random generation,
#' survival function, and hazard rate function for the Modified Topp-Leone (MTL)
#' distribution with shape parameter \code{alpha}.
#'
#' @param x,q Vector of quantiles.
#' @param p Vector of probabilities.
#' @param n Number of observations. If \code{length(n) > 1}, the length is taken to be the number required.
#' @param alpha Shape parameter of the MTL distribution (\code{alpha > 0}).
#' @param log,log.p Logical; if \code{TRUE}, probabilities/densities \eqn{p} are given as \eqn{\log(p)}. Default is \code{FALSE}.
#' @param lower.tail Logical; if \code{TRUE} (default), probabilities are \eqn{P[X \le x]}, otherwise \eqn{P[X > x]}.
#'
#' @details
#' The probability density function (PDF) of the Modified Topp-Leone distribution is given by:
#' \deqn{f(x; \alpha) = 2 \alpha (1 + x)^{-(2\alpha + 1)} (2x + x^2)^{\alpha - 1}, \quad x > 0, \; \alpha > 0}
#' The cumulative distribution function (CDF) is given by:
#' \deqn{F(x; \alpha) = \left( \frac{2x + x^2}{(1 + x)^2} \right)^\alpha = \left( 1 - \frac{1}{(1 + x)^2} \right)^\alpha, \quad x > 0, \; \alpha > 0}
#' The quantile function is derived by inverting the CDF:
#' \deqn{Q(p; \alpha) = (1 - p^{1/\alpha})^{-1/2} - 1, \quad 0 < p < 1}
#'
#' @return
#' \code{dmtl} gives the density, \code{pmtl} gives the distribution function,
#' \code{qmtl} gives the quantile function, \code{rmtl} generates random deviates,
#' \code{smtl} gives the survival function, and \code{hmtl} gives the hazard rate function.
#'
#' @references
#' Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
#' Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
#' and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
#'
#' @author Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
#'
#' @examples
#' # Evaluate PDF and CDF at x = 1 with alpha = 1.5
#' dmtl(x = 1, alpha = 1.5)
#' pmtl(q = 1, alpha = 1.5)
#'
#' # Quantile function and random generation
#' p_seq <- c(0.25, 0.50, 0.75)
#' qmtl(p = p_seq, alpha = 1.5)
#' set.seed(123)
#' x_sample <- rmtl(n = 10, alpha = 1.5)
#' x_sample
#'
#' # Survival and Hazard functions
#' smtl(x = 1, alpha = 1.5)
#' hmtl(x = 1, alpha = 1.5)
#'
#' @name ModToppLeone
#' @rdname ModToppLeone
#' @export
dmtl <- function(x, alpha, log = FALSE) {
  if (missing(alpha) || any(alpha <= 0)) {
    stop("Parameter 'alpha' must be positive.")
  }
  
  pdf_val <- numeric(length(x))
  
  valid_idx <- !is.na(x) & x > 0
  if (any(valid_idx)) {
    xv <- x[valid_idx]
    
    log_pdf <- log(2) + log(alpha) + (alpha - 1) * log(xv * (2 + xv)) - (2 * alpha + 1) * log(1 + xv)
    if (log) {
      pdf_val[valid_idx] <- log_pdf
    } else {
      pdf_val[valid_idx] <- exp(log_pdf)
    }
  }
  
  invalid_idx <- !is.na(x) & x <= 0
  if (any(invalid_idx)) {
    pdf_val[invalid_idx] <- if (log) -Inf else 0
  }
  
  pdf_val[is.na(x)] <- NA
  return(pdf_val)
}

#' @rdname ModToppLeone
#' @export
pmtl <- function(q, alpha, lower.tail = TRUE, log.p = FALSE) {
  if (missing(alpha) || any(alpha <= 0)) {
    stop("Parameter 'alpha' must be positive.")
  }
  
  cdf_val <- numeric(length(q))
  
  valid_idx <- !is.na(q) & q > 0
  if (any(valid_idx)) {
    qv <- q[valid_idx]
    
    base_val <- 1 - (1 + qv)^(-2)
    base_val <- pmax(pmin(base_val, 1), 0)
    
    if (lower.tail) {
      if (log.p) {
        cdf_val[valid_idx] <- alpha * log(base_val)
      } else {
        cdf_val[valid_idx] <- base_val^alpha
      }
    } else {
      surv <- 1 - base_val^alpha
      surv <- pmax(pmin(surv, 1), 0)
      if (log.p) {
        cdf_val[valid_idx] <- log(surv)
      } else {
        cdf_val[valid_idx] <- surv
      }
    }
  }
  
  invalid_idx <- !is.na(q) & q <= 0
  if (any(invalid_idx)) {
    if (lower.tail) {
      cdf_val[invalid_idx] <- if (log.p) -Inf else 0
    } else {
      cdf_val[invalid_idx] <- if (log.p) 0 else 1
    }
  }
  
  cdf_val[is.na(q)] <- NA
  return(cdf_val)
}

#' @rdname ModToppLeone
#' @export
qmtl <- function(p, alpha, lower.tail = TRUE, log.p = FALSE) {
  if (missing(alpha) || any(alpha <= 0)) {
    stop("Parameter 'alpha' must be positive.")
  }
  
  if (log.p) {
    p <- exp(p)
  }
  if (!lower.tail) {
    p <- 1 - p
  }
  
  q_val <- numeric(length(p))
  
  out_of_bounds <- !is.na(p) & (p < 0 | p > 1)
  if (any(out_of_bounds)) {
    warning("Probabilities outside [0, 1] produced NaNs.")
    q_val[out_of_bounds] <- NaN
  }
  
  valid_idx <- !is.na(p) & p > 0 & p < 1
  if (any(valid_idx)) {
    pv <- p[valid_idx]
    q_val[valid_idx] <- (1 - pv^(1 / alpha))^(-0.5) - 1
  }
  
  zero_idx <- !is.na(p) & p == 0
  if (any(zero_idx)) {
    q_val[zero_idx] <- 0
  }
  
  one_idx <- !is.na(p) & p == 1
  if (any(one_idx)) {
    q_val[one_idx] <- Inf
  }
  
  q_val[is.na(p)] <- NA
  return(q_val)
}

#' @rdname ModToppLeone
#' @export
rmtl <- function(n, alpha) {
  if (missing(alpha) || any(alpha <= 0)) {
    stop("Parameter 'alpha' must be positive.")
  }
  
  if (length(n) > 1) {
    n <- length(n)
  }
  if (is.na(n) || n <= 0) {
    stop("Sample size 'n' must be a positive integer.")
  }
  
  u <- stats::runif(n)
  x <- (1 - u^(1 / alpha))^(-0.5) - 1
  return(x)
}

#' @rdname ModToppLeone
#' @export
smtl <- function(x, alpha, log.p = FALSE) {
  return(pmtl(q = x, alpha = alpha, lower.tail = FALSE, log.p = log.p))
}

#' @rdname ModToppLeone
#' @export
hmtl <- function(x, alpha, log = FALSE) {
  pdf <- dmtl(x = x, alpha = alpha, log = FALSE)
  surv <- smtl(x = x, alpha = alpha, log.p = FALSE)
  
  hrf <- pdf / surv
  hrf[surv <= 0] <- Inf
  hrf[x <= 0] <- 0
  
  if (log) {
    return(log(hrf))
  } else {
    return(hrf)
  }
}

---
title: "Modified Topp-Leone Distribution: Properties, Estimation, and Applications"
author: "Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{Modified Topp-Leone Distribution: Properties, Estimation, and Applications}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  fig.width = 6,
  fig.height = 4
)
library(ModToppLeone)
```

## Introduction

The **`ModToppLeone`** package provides comprehensive tools for working with the Modified Topp-Leone (MTL) distribution, introduced by Singh, Tyagi, Singh, and Tyagi (2025). The MTL distribution is a flexible single-parameter lifetime model obtained via the transformation $Y = X / (1 - X)$ where $X$ follows the classical Topp-Leone distribution.

The probability density function (PDF) and cumulative distribution function (CDF) of the MTL distribution with shape parameter $\alpha > 0$ are given by:

$$f(y; \alpha) = 2 \alpha (1 + y)^{-(2\alpha + 1)} (2y + y^2)^{\alpha - 1}, \quad y > 0$$

$$F(y; \alpha) = \left( 1 - \frac{1}{(1 + y)^2} \right)^\alpha, \quad y > 0$$

## Core Distribution Functions

The package provides standard distribution functions: `dmtl`, `pmtl`, `qmtl`, `rmtl`, `smtl`, and `hmtl`.

```{r core_funcs}
# Density and CDF
dmtl(x = 1.0, alpha = 1.5)
pmtl(q = 1.0, alpha = 1.5)

# Quantile function and Random Generation
qmtl(p = c(0.25, 0.50, 0.75), alpha = 1.5)

set.seed(123)
sample_data <- rmtl(n = 10, alpha = 1.5)
sample_data

# Survival and Hazard Rate Functions
smtl(x = 1.0, alpha = 1.5)
hmtl(x = 1.0, alpha = 1.5)
```

## Statistical Properties

The package includes helper functions to derive theoretical statistical properties:

```{r properties}
# Mode and Mean
mode_mtl(alpha = 2.5)
mean_mtl(alpha = 1.5)

# Quantiles summary (Median, Skewness, Kurtosis)
quantiles_mtl(alpha = 1.5)

# Mean Deviations about mean and median
meandev_mtl(alpha = 1.5)

# Stress-Strength Reliability P(Y2 < Y1)
ssr_mtl(alpha1 = 2, alpha2 = 3)
```

## Classical Estimation Methods

The parameter $\alpha$ can be estimated using five classical point estimation procedures: Maximum Likelihood (MLE), Ordinary Least Squares (OLS), Weighted Least Squares (WLS), Cramér-von Mises (CVM), and Maximum Product of Spacings (MPS).

```{r classical_fit}
set.seed(42)
sim_data <- rmtl(n = 50, alpha = 2.0)

# Unified estimation wrapper
fit_results <- fit_mtl(x = sim_data, method = "all")
fit_results
```

## Bayesian Estimation

Bayesian estimation is supported under both informative (Gamma) and non-informative priors with symmetric (SELF) and asymmetric (ELF, PLF, GELF) loss functions, alongside Chen-Shao Highest Posterior Density (HPD) intervals.

```{r bayes_fit}
# Non-informative prior Bayesian estimation
bayes_res <- bayes_mtl(x = sim_data, prior = "noninformative", loss = "all")
bayes_res$estimates
bayes_res$hpd
```

## Censoring Schemes

The package supports sample generation and parameter estimation under various censoring schemes, including Random Right Censoring, Type-I, Type-II, and Progressive Type-II Censoring.

```{r censoring}
# Progressive Type-II Censoring example
R_scheme <- c(2, 0, 1, 0, 2)
prog_sample <- rcensor_mtl(n = 10, alpha = 2.0, scheme = "progressive2", m = 5, R = R_scheme)

mle_censor_mtl(x = prog_sample$x, scheme = "progressive2", R = R_scheme)
```

## Real Datasets

The package includes three benchmark real datasets analyzed in the research paper:

1. `dataset_air`: Air conditioning failure times of Boeing 720 jet airplanes.
2. `dataset_covid_india`: Daily new COVID-19 cases in India.
3. `dataset_covid_france`: Daily new COVID-19 cases in France.

```{r datasets}
data(dataset_air)
mle_mtl(dataset_air)
```

## References

- Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19 and Reliability Data. *Thailand Statistician*, 23(1), 72-96.

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation_bayes.R
\name{bayes_mtl}
\alias{bayes_mtl}
\title{Bayesian Estimation for the Modified Topp-Leone Distribution}
\usage{
bayes_mtl(
  x,
  prior = c("informative", "noninformative"),
  a = 1,
  b = 1,
  loss = c("self", "elf", "plf", "gelf", "all"),
  delta = 1,
  n.draws = 10000,
  burn.in = 1000,
  thin = 1,
  conf.level = 0.95
)
}
\arguments{
\item{x}{Vector of sample observations (\code{x > 0}).}

\item{prior}{Type of prior distribution: \code{"informative"} (Gamma(a, b)) or \code{"noninformative"} (\code{a = 0, b = 0}).}

\item{a}{Shape parameter for Gamma prior (hyperparameter \code{a > 0}).}

\item{b}{Rate parameter for Gamma prior (hyperparameter \code{b > 0}).}

\item{loss}{Loss function: \code{"self"} (Squared Error Loss), \code{"elf"} (Entropy Loss),
\code{"plf"} (Precautionary Loss), \code{"gelf"} (Generalized Entropy Loss), or \code{"all"}.}

\item{delta}{Constant for Generalized Entropy Loss Function (\code{delta != 0}). Default is 1.}

\item{n.draws}{Number of MCMC iterations (default: 10000).}

\item{burn.in}{Number of initial draws to discard as burn-in (default: 1000).}

\item{thin}{Thinning interval for MCMC chain (default: 1).}

\item{conf.level}{Credible level for HPD interval estimation (default: 0.95).}
}
\value{
A list containing point estimates under specified loss functions, posterior standard error (PSE),
posterior summary statistics, MCMC sample draws, and the 100*(1 - alpha)\% HPD interval.
}
\description{
Estimates the shape parameter \code{alpha} of the Modified Topp-Leone (MTL) distribution
under informative (Gamma) and non-informative priors using symmetric (SELF) and asymmetric
(ELF, PLF, GELF) loss functions, along with Chen-Shao Highest Posterior Density (HPD) intervals.
}
\examples{
set.seed(123)
sample_data <- rmtl(n = 30, alpha = 2.5)

# Bayesian Estimation under Non-informative Prior
bayes_mtl(x = sample_data, prior = "noninformative", loss = "all")

# Bayesian Estimation under Informative Prior (a = 2, b = 1)
bayes_mtl(x = sample_data, prior = "informative", a = 2, b = 1, loss = "self")

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.

Chen, M. H., and Shao, Q. M. (1999). Monte Carlo estimation of Bayesian credible and HPD intervals.
\emph{Journal of Computational and Graphical Statistics}, 8(1), 69-92.

Calabria, R., and Pulcini, G. (1996). Point estimation under asymmetric loss functions for left-truncated
exponential samples. \emph{Communications in Statistics - Theory and Methods}, 25(3), 585-600.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot.R
\name{plot_mtl}
\alias{plot_mtl}
\title{Diagnostic and Visualization Plots for the Modified Topp-Leone Distribution}
\usage{
plot_mtl(
  alpha = c(0.5, 1.5, 3, 10),
  type = c("pdf", "cdf", "sf", "hrf"),
  x_max = 10,
  n_points = 500
)
}
\arguments{
\item{alpha}{Vector of shape parameter values (\code{alpha > 0}).}

\item{type}{Type of plot: \code{"pdf"}, \code{"cdf"}, \code{"sf"}, or \code{"hrf"}.}

\item{x_max}{Maximum value of x on the horizontal axis (default: 10).}

\item{n_points}{Number of evaluation points along the x-axis (default: 500).}
}
\value{
No return value, called for side effects (produces a plot).
}
\description{
Plot probability density function (PDF), cumulative distribution function (CDF),
survival function (SF), or hazard rate function (HRF) of the Modified Topp-Leone (MTL)
distribution for specified values of \code{alpha}.
}
\examples{
# Plot PDF for various values of alpha
plot_mtl(alpha = c(0.5, 1.5, 3.0, 10.0), type = "pdf", x_max = 5)

# Plot HRF for various values of alpha
plot_mtl(alpha = c(0.5, 1.5, 3.0, 10.0), type = "hrf", x_max = 5)

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/properties.R
\name{properties_mtl}
\alias{properties_mtl}
\alias{mode_mtl}
\alias{mean_mtl}
\alias{moments_mtl}
\alias{quantiles_mtl}
\alias{meandev_mtl}
\alias{inequality_mtl}
\alias{mrl_mtl}
\alias{mpl_mtl}
\alias{pwm_mtl}
\alias{entropy_mtl}
\alias{ssr_mtl}
\alias{order_stats_mtl}
\title{Statistical Properties of the Modified Topp-Leone Distribution}
\usage{
mode_mtl(alpha)

mean_mtl(alpha, n_terms = 100)

moments_mtl(r, alpha, n_terms = 100)

quantiles_mtl(alpha)

meandev_mtl(alpha)

inequality_mtl(y, alpha)

mrl_mtl(y, alpha)

mpl_mtl(y, alpha)

pwm_mtl(r, s, alpha)

entropy_mtl(alpha, type = c("shannon", "renyi", "omega"), gamma = 0.5)

ssr_mtl(alpha1, alpha2)

order_stats_mtl(y, alpha, n, u, type = c("pdf", "cdf"))
}
\arguments{
\item{alpha}{Shape parameter of the MTL distribution (\code{alpha > 0}).}

\item{n_terms}{Number of terms to use in series expansions (default: 100).}

\item{r}{Order of the raw moment or probability-weighted moment.}

\item{y}{Evaluation point for residual life, past life, inequality curves, or order statistics.}

\item{s}{Parameter for probability-weighted moment.}

\item{type}{Type of entropy (\code{"renyi"}, \code{"shannon"}, or \code{"omega"}) or order statistics output (\code{"pdf"} or \code{"cdf"}).}

\item{gamma}{Order parameter for Rényi or \eqn{\omega}-entropy (\code{gamma > 0, gamma != 1}).}

\item{alpha1, alpha2}{Shape parameters for two independent MTL variables in stress-strength reliability.}

\item{n}{Sample size for order statistics.}

\item{u}{Index of the order statistic (\code{1 <= u <= n}).}
}
\value{
Numeric scalar or vector corresponding to the calculated statistical property:
\itemize{
  \item \code{mode_mtl}: Mode of the MTL distribution.
  \item \code{mean_mtl}: Mean of the MTL distribution.
  \item \code{moments_mtl}: $r$-th raw moment (finite for $r = 1$).
  \item \code{quantiles_mtl}: Named vector of quantiles, median, skewness, and kurtosis.
  \item \code{meandev_mtl}: Mean deviation about mean and median.
  \item \code{inequality_mtl}: Lorenz, Bonferroni, and Zenga inequality measures.
  \item \code{mrl_mtl}: Mean residual life function.
  \item \code{mpl_mtl}: Mean past life (expected inactivity time) function.
  \item \code{pwm_mtl}: Probability-weighted moment \eqn{\mu_{r,s}}.
  \item \code{entropy_mtl}: Specified entropy measure.
  \item \code{ssr_mtl}: Stress-strength reliability \eqn{R = P[Y_2 < Y_1]}.
  \item \code{order_stats_mtl}: Density or CDF of the $u$-th order statistic.
}
}
\description{
Functions to calculate various statistical properties of the Modified Topp-Leone (MTL)
distribution including mode, mean, quantiles, mean deviations, inequality measures,
mean residual life, mean past life, probability-weighted moments, entropies,
stress-strength reliability, and order statistics.
}
\examples{
# Mode and Mean
mode_mtl(alpha = 2.5)
mean_mtl(alpha = 1.5)

# Quantiles summary
quantiles_mtl(alpha = 1.5)

# Mean deviations
meandev_mtl(alpha = 1.5)

# Inequality measures at y = 1
inequality_mtl(y = 1, alpha = 1.5)

# Mean residual life and past life
mrl_mtl(y = 1, alpha = 1.5)
mpl_mtl(y = 1, alpha = 1.5)

# Entropies
entropy_mtl(alpha = 1.5, type = "shannon")
entropy_mtl(alpha = 1.5, type = "renyi", gamma = 0.5)

# Stress-Strength Reliability
ssr_mtl(alpha1 = 2, alpha2 = 3)

# Order statistics density for median in n = 5 sample
order_stats_mtl(y = 1, alpha = 1.5, n = 5, u = 3, type = "pdf")

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dmtl.R
\name{ModToppLeone}
\alias{ModToppLeone}
\alias{dmtl}
\alias{pmtl}
\alias{qmtl}
\alias{rmtl}
\alias{smtl}
\alias{hmtl}
\title{The Modified Topp-Leone Distribution}
\usage{
dmtl(x, alpha, log = FALSE)

pmtl(q, alpha, lower.tail = TRUE, log.p = FALSE)

qmtl(p, alpha, lower.tail = TRUE, log.p = FALSE)

rmtl(n, alpha)

smtl(x, alpha, log.p = FALSE)

hmtl(x, alpha, log = FALSE)
}
\arguments{
\item{x, q}{Vector of quantiles.}

\item{alpha}{Shape parameter of the MTL distribution (\code{alpha > 0}).}

\item{log, log.p}{Logical; if \code{TRUE}, probabilities/densities \eqn{p} are given as \eqn{\log(p)}. Default is \code{FALSE}.}

\item{lower.tail}{Logical; if \code{TRUE} (default), probabilities are \eqn{P[X \le x]}, otherwise \eqn{P[X > x]}.}

\item{p}{Vector of probabilities.}

\item{n}{Number of observations. If \code{length(n) > 1}, the length is taken to be the number required.}
}
\value{
\code{dmtl} gives the density, \code{pmtl} gives the distribution function,
\code{qmtl} gives the quantile function, \code{rmtl} generates random deviates,
\code{smtl} gives the survival function, and \code{hmtl} gives the hazard rate function.
}
\description{
Density, distribution function, quantile function, random generation,
survival function, and hazard rate function for the Modified Topp-Leone (MTL)
distribution with shape parameter \code{alpha}.
}
\details{
The probability density function (PDF) of the Modified Topp-Leone distribution is given by:
\deqn{f(x; \alpha) = 2 \alpha (1 + x)^{-(2\alpha + 1)} (2x + x^2)^{\alpha - 1}, \quad x > 0, \; \alpha > 0}
The cumulative distribution function (CDF) is given by:
\deqn{F(x; \alpha) = \left( \frac{2x + x^2}{(1 + x)^2} \right)^\alpha = \left( 1 - \frac{1}{(1 + x)^2} \right)^\alpha, \quad x > 0, \; \alpha > 0}
The quantile function is derived by inverting the CDF:
\deqn{Q(p; \alpha) = (1 - p^{1/\alpha})^{-1/2} - 1, \quad 0 < p < 1}
}
\examples{
# Evaluate PDF and CDF at x = 1 with alpha = 1.5
dmtl(x = 1, alpha = 1.5)
pmtl(q = 1, alpha = 1.5)

# Quantile function and random generation
p_seq <- c(0.25, 0.50, 0.75)
qmtl(p = p_seq, alpha = 1.5)
set.seed(123)
x_sample <- rmtl(n = 10, alpha = 1.5)
x_sample

# Survival and Hazard functions
smtl(x = 1, alpha = 1.5)
hmtl(x = 1, alpha = 1.5)

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/censoring.R
\name{censoring_mtl}
\alias{censoring_mtl}
\alias{rcensor_mtl}
\alias{mle_censor_mtl}
\title{Censoring Schemes and Estimation for the Modified Topp-Leone Distribution}
\usage{
rcensor_mtl(
  n,
  alpha,
  scheme = c("random", "type1", "type2", "progressive2"),
  T_censor = NULL,
  m = NULL,
  R = NULL,
  censor_rate = 0.5
)

mle_censor_mtl(
  x,
  status = NULL,
  scheme = c("random", "type1", "type2", "progressive2"),
  R = NULL,
  conf.level = 0.95
)
}
\arguments{
\item{n}{Total initial sample size.}

\item{alpha}{Shape parameter of the MTL distribution (\code{alpha > 0}).}

\item{scheme}{Type of censoring scheme: \code{"random"}, \code{"type1"}, \code{"type2"}, or \code{"progressive2"}.}

\item{T_censor}{Fixed censoring time for Type-I censoring (\code{T_censor > 0}).}

\item{m}{Number of observed failures for Type-II or Progressive Type-II censoring (\code{1 <= m <= n}).}

\item{R}{Vector of removal counts for Progressive Type-II censoring of length \code{m} such that \code{sum(R) == n - m}.}

\item{censor_rate}{Rate parameter for exponential censoring distribution in random censoring.}

\item{x}{Vector of observed failure/censoring times.}

\item{status}{Vector of censoring indicators (1 = observed failure, 0 = censored).}

\item{conf.level}{Confidence level for interval estimation (default: 0.95).}
}
\value{
\code{rcensor_mtl} returns a list containing observed times (\code{x}), censoring status (\code{status}),
censoring scheme info, and parameter settings.
\code{mle_censor_mtl} returns a list containing point estimate (\code{estimate}), standard error (\code{se}),
asymptotic confidence interval (\code{ci}), and log-likelihood value under censoring.
}
\description{
Functions to generate random samples and estimate parameters of the Modified Topp-Leone (MTL)
distribution under various censoring schemes: Random Right Censoring, Type-I Censoring,
Type-II Censoring, and Progressive Type-II Censoring.
}
\examples{
set.seed(123)
# 1. Random Right Censoring
rand_cens <- rcensor_mtl(n = 30, alpha = 2.0, scheme = "random", censor_rate = 0.5)
mle_censor_mtl(x = rand_cens$x, status = rand_cens$status, scheme = "random")

# 2. Type-I Censoring
t1_cens <- rcensor_mtl(n = 30, alpha = 2.0, scheme = "type1", T_censor = 1.5)
mle_censor_mtl(x = t1_cens$x, status = t1_cens$status, scheme = "type1")

# 3. Type-II Censoring
t2_cens <- rcensor_mtl(n = 30, alpha = 2.0, scheme = "type2", m = 20)
mle_censor_mtl(x = t2_cens$x, status = t2_cens$status, scheme = "type2")

# 4. Progressive Type-II Censoring
R_scheme <- c(2, 0, 1, 0, 2, 0, 1, 0, 2, 2)
prog_cens <- rcensor_mtl(n = 20, alpha = 2.0, scheme = "progressive2", m = 10, R = R_scheme)
mle_censor_mtl(x = prog_cens$x, scheme = "progressive2", R = R_scheme)

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.

Balakrishnan, N., and Aggarwala, R. (2000). \emph{Progressive Censoring: Theory, Methods, and Applications}.
Birkhäuser, Boston.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimation_classical.R
\name{classical_mtl}
\alias{classical_mtl}
\alias{mle_mtl}
\alias{ols_mtl}
\alias{wls_mtl}
\alias{cvm_mtl}
\alias{mps_mtl}
\alias{fit_mtl}
\title{Classical Estimation Methods for the Modified Topp-Leone Distribution}
\usage{
mle_mtl(x, conf.level = 0.95)

ols_mtl(x)

wls_mtl(x)

cvm_mtl(x)

mps_mtl(x)

fit_mtl(
  x,
  method = c("mle", "ols", "wls", "cvm", "mps", "all"),
  conf.level = 0.95
)
}
\arguments{
\item{x}{Vector of sample observations (\code{x > 0}).}

\item{conf.level}{Confidence level for interval estimation (default: 0.95).}

\item{method}{Estimation method: \code{"mle"}, \code{"ols"}, \code{"wls"}, \code{"cvm"}, \code{"mps"}, or \code{"all"}.}
}
\value{
A list or data frame containing point estimate, standard error, asymptotic confidence interval,
log-likelihood, AIC, BIC, CAIC, Kolmogorov-Smirnov test statistic, and associated p-value.
}
\description{
Point and interval estimation of the shape parameter \code{alpha} of the
Modified Topp-Leone (MTL) distribution using classical methods: Maximum Likelihood (MLE),
Ordinary Least Squares (OLS), Weighted Least Squares (WLS), Cramér-von Mises (CVM),
and Maximum Product of Spacings (MPS).
}
\examples{
set.seed(123)
sample_data <- rmtl(n = 50, alpha = 2.0)

# MLE Estimation
mle_mtl(x = sample_data)

# OLS and WLS Estimation
ols_mtl(x = sample_data)
wls_mtl(x = sample_data)

# CVM and MPS Estimation
cvm_mtl(x = sample_data)
mps_mtl(x = sample_data)

# Fit all classical methods simultaneously
fit_mtl(x = sample_data, method = "all")

}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.

Cheng, R. C. H., and Amin, N. A. K. (1983). Estimating parameters in continuous univariate
distributions with a shifted origin. \emph{Journal of the Royal Statistical Society: Series B}, 45(3), 394-403.

Swain, J. J., Venkatraman, S., and Wilson, J. R. (1988). Least-squares estimation of distribution
functions in Johnson's translation system. \emph{Journal of Statistical Computation and Simulation}, 29(4), 271-297.
}
\author{
Shikhar Tyagi, Abhishek Tyagi, Arvind Pandey, Bhupendra Singh, Vrijesh Tripathi
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{real_datasets}
\alias{real_datasets}
\alias{dataset_air}
\alias{dataset_covid_india}
\alias{dataset_covid_france}
\title{Real Datasets used in Modified Topp-Leone Research Paper}
\format{
Numeric vectors containing positive observations:
\describe{
  \item{dataset_air}{Number of successive failures for the air conditioning system of each member in a fleet of 13 Boeing 720 jet airplanes (divided by 100 for fitting convenience).}
  \item{dataset_covid_india}{Daily new COVID-19 cases in India from 16 March 2021 to 16 April 2021 (divided by 10,000).}
  \item{dataset_covid_france}{Daily new COVID-19 cases in France from 5 August 2020 to 5 November 2020 (divided by 10,000).}
}

An object of class \code{numeric} of length 39.

An object of class \code{numeric} of length 50.
}
\usage{
dataset_air

dataset_covid_india

dataset_covid_france
}
\description{
Three real-world datasets examined in Singh et al. (2025) to illustrate the flexibility and
applicability of the Modified Topp-Leone distribution.
}
\examples{
data(dataset_air)
mle_mtl(dataset_air)

data(dataset_covid_india)
fit_mtl(dataset_covid_india, method = "all")

data(dataset_covid_france)
bayes_mtl(dataset_covid_france, prior = "noninformative")
}
\references{
Singh, B., Tyagi, S., Singh, R. P., and Tyagi, A. (2025). Modified Topp-Leone
Distribution: Properties, Classical and Bayesian Estimation with Application to COVID-19
and Reliability Data. \emph{Thailand Statistician}, 23(1), 72-96.

Cordeiro, G. M., and Lemonte, A. J. (2011). The beta-Birnbaum-Saunders distribution:
An improved distribution for fatigue life modelling. \emph{Computational Statistics & Data Analysis}, 55(3), 1445-1461.
}
\keyword{datasets}
